API docs for “spamfighter.core.message.test.test_message.TaggedMessageTestCase”

# Class s.c.m.t.t.TaggedMessageTestCase(unittest.TestCase):

Part of spamfighter.core.message.test.test_message View Source View In Hierarchy

Тест на `spamfighter.core.message.message.TaggedMessage`.

Method | setUp | Undocumented
Method | testInterface | Undocumented
Method | testCheckHasAllTags | Undocumented
Method | testCheckHasNoTags | Undocumented
Method | testConstructFromMessage | Undocumented
Method | testGetTags | Undocumented

def setUp(self): (source)
Undocumented
def testInterface(self): (source)
Undocumented
def testCheckHasAllTags(self): (source)
Undocumented
def testCheckHasNoTags(self): (source)
Undocumented
def testConstructFromMessage(self): (source)
Undocumented
def testGetTags(self): (source)
Undocumented